@@ -22,6 +22,4 @@ def get_event_data(event, schema, schema_id, version, unredacted_policies):
     e.emit(schema_id, version, deepcopy(event))
 
     recorded_event = json.loads(sink.getvalue())
-    return {
-        key: value for key, value in recorded_event.items() if not key.startswith("__")
-    }
+    return {key: value for key, value in recorded_event.items() if not key.startswith("__")}
